Config

Struct Config 

pub struct Config {
    pub allow_credentials: bool,
    pub allowed_headers: AllowedHeaders,
    pub allowed_methods: AllowedMethods,
    pub allowed_origins: AllowedOrigins,
    pub allow_private_network: bool,
    pub max_age: Option<Duration>,
    pub expose_headers: ExposeHeaders,
    pub vary: Vary,
}

Fields

allow_credentials: bool

Whether to allow credentials in CORS requests

allowed_headers: AllowedHeaders

Which request headers can be sent in the actual request. Controls the Access-Control-Allow-Headers response header.

allowed_methods: AllowedMethods

Controls how to set the Access-Control-Allow-Methods response header.

allowed_origins: AllowedOrigins

Controls how to set the Access-Control-Allow-Origin response header.

allow_private_network: bool

If true, include the Access-Control-Allow-Private-Network response header.

max_age: Option<Duration>

The maximum age of the CORS request in seconds

expose_headers: ExposeHeaders

Which headers are exposed to the client. Controls the Access-Control-Expose-Headers response header.

vary: Vary

Which headers to set in the Vary response header